summaryrefslogtreecommitdiffstats
path: root/lib/compatibility/kmdi/qextmdi/kmditaskbar.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/compatibility/kmdi/qextmdi/kmditaskbar.h')
-rw-r--r--lib/compatibility/kmdi/qextmdi/kmditaskbar.h34
1 files changed, 17 insertions, 17 deletions
diff --git a/lib/compatibility/kmdi/qextmdi/kmditaskbar.h b/lib/compatibility/kmdi/qextmdi/kmditaskbar.h
index f1aac814..c333070a 100644
--- a/lib/compatibility/kmdi/qextmdi/kmditaskbar.h
+++ b/lib/compatibility/kmdi/qextmdi/kmditaskbar.h
@@ -29,10 +29,10 @@
#define _KMDITASKBAR_H_
#include <ktoolbar.h>
-#include <qptrlist.h>
-#include <qpixmap.h>
-#include <qlabel.h>
-#include <qpushbutton.h>
+#include <tqptrlist.h>
+#include <tqpixmap.h>
+#include <tqlabel.h>
+#include <tqpushbutton.h>
#include "kmdidefines.h"
@@ -45,7 +45,7 @@ class KMdiTaskBarButtonPrivate;
/**
* @short Internal class.
*
- * It's a special kind of QPushButton catching mouse clicks.
+ * It's a special kind of TQPushButton catching mouse clicks.
* And you have the ability to abbreviate the text that it fits in the button.
*/
class KMdiTaskBarButton : public QPushButton
@@ -64,15 +64,15 @@ public:
/**
* text() returns the possibly abbreviated text including the dots in it. But actualText() returns the full text.
*/
- QString actualText() const;
+ TQString actualText() const;
/**
* Given the parameter newWidth this function possibly abbreviates the parameter string and sets a new button text.
*/
- void fitText( const QString&, int newWidth );
+ void fitText( const TQString&, int newWidth );
/**
* Sets the text and avoids any abbreviation. Memorizes that text in m_actualText, too.
*/
- void setText( const QString& );
+ void setText( const TQString& );
signals:
/**
* Emitted when the button has been clicked. Internally connected to setFocus of the according MDI view.
@@ -94,12 +94,12 @@ public slots:
/**
* A slot version of setText
*/
- void setNewText( const QString& );
+ void setNewText( const TQString& );
protected slots:
/**
* Reimplemented from its base class to catch right and left mouse button clicks
*/
- void mousePressEvent( QMouseEvent* );
+ void mousePressEvent( TQMouseEvent* );
// attributes
public:
@@ -111,7 +111,7 @@ protected:
/**
* Internally we must remember the real text because the button text can be abbreviated.
*/
- QString m_actualText;
+ TQString m_actualText;
private:
KMdiTaskBarButtonPrivate *d;
@@ -122,7 +122,7 @@ class KMdiTaskBarPrivate;
/**
* @short Internal class.
*
- * It's a special kind of QToolBar that acts as taskbar for child views.
+ * It's a special kind of TQToolBar that acts as taskbar for child views.
* KMdiTaskBarButtons can be added or removed dynamically.<br>
* The button sizes are adjusted dynamically, as well.
*/
@@ -131,9 +131,9 @@ class KMDI_EXPORT KMdiTaskBar : public KToolBar
Q_OBJECT
public:
/**
* Constructor (NoFocus, minimum width = 1, an internal QPtrList of taskbar buttons (autodelete))
*/
- KMdiTaskBar( KMdiMainFrm *parent, QMainWindow::ToolBarDock dock );
+ KMdiTaskBar( KMdiMainFrm *parent, TQMainWindow::ToolBarDock dock );
/**
* Destructor (deletes the taskbar button list)
*/
@@ -173,7 +173,7 @@ protected:
/**
* Reimplemented from its base class to call layoutTaskBar, additionally.
*/
- void resizeEvent( QResizeEvent* );
+ void resizeEvent( TQResizeEvent* );
protected slots:
/**
* Checks if all buttons fits into this. If not, it recalculates all button widths
@@ -194,7 +194,7 @@ protected:
* A list of taskbar buttons.
* Note: Each button stands for one MDI view (toolviews doesn't have got a taskbar button).
*/
- QPtrList<KMdiTaskBarButton>* m_pButtonList;
+ TQPtrList<KMdiTaskBarButton>* m_pButtonList;
/**
* The belonging MDI mainframe (parent widget of this)
*/
@@ -206,7 +206,7 @@ protected:
/**
* A stretchable widget used as 'space' at the end of a half filled taskbar
*/
- QLabel* m_pStretchSpace;
+ TQLabel* m_pStretchSpace;
bool m_layoutIsPending;
bool m_bSwitchedOn;
@@ -131,9 +131,9 @@ class KMDI_EXPORT KMdiTaskBar : public KToolBar
public:
/**
- * Constructor (NoFocus, minimum width = 1, an internal QPtrList of taskbar buttons (autodelete))
+ * Constructor (NoFocus, minimum width = 1, an internal TQPtrList of taskbar buttons (autodelete))
*/